'''
    Class Receiver
    
    
'''

import configparser
from RPLCD import CharLCD
import xml.etree.cElementTree as ET
import os

#
# Constants

# Text file where the last station index listened is recorded before switch off
LASTSTATION = "lastStation.txt"


class Receiver:


    def __init__(self, XMLStationListFile):
        # Input parameters
        #   XMLstationListFile: XML file listing URL and captions of available stations
        #

        # Table of captions for displaying the name of stations
        self.stationCaption = []

        # Load the list of available web stations (URL and caption) 
        # from an XML file, and setup MPC application
    
        # MPC init
        # Clear the tracklist and rebuilt it from configuration file
        os.system("mpc clear")

        # Init parsing of the XML file to extract all the radio stations
        tree = ET.parse(XMLStationListFile)
        root = tree.getroot()
        for child in root:
            # Look for next radio station to add
            if child.tag == "station":
                # Add the station URL to MPC
                url = child.attrib["url"]
                os.system("mpc add " + url)
                # Add the corresponding caption to the list
                newcaption = child.attrib["caption"]
                self.stationCaption.append(newcaption)
                print("Station " + newcaption + " added")
                
        if len(self.stationCaption) > 0:
            print("Total of " + str(len(self.stationCaption)) + " radio stations")
        else:
            print("No station available, quitting application")
            quit()
        
        # Get the latest track listened before last switch off
        # The track index was stored in the file LASTSTATION
        try:
            f = open(LASTSTATION, "r")
            self.curStation = int(f.read())
            f.close()
            if self.curStation <= len(self.stationCaption):
                print("Restored station " + str(self.curStation) + ": " + self.stationCaption[self.curStation-1])
            else:
                print("Restored station does not exist")
                self.curStation = 1
    
        except (OSError, IOError, ValueError):
            self.curStation = 1
            print ("Error restoring current station");
            
        self.volume = 0

    def getNumberOfStations(self):
        #
        # Accessor, returns the number of available stations
        return self.len(self.stationCaption)
    
    def getStationName(self):
        #
        # Returns name (caption) of current station
        return self.stationCaption[self.curStation-1]
            
    def play(self):
        #
        # Start playing the station with MPC
        # Returns: Caption of the played station
        os.system("mpc play " + str(self.curStation))
        return self.stationCaption[self.curStation-1]
             

    def stop(self):
        #
        # Record the current listened station and stop playing
        
        os.system("mpc stop")    
        # Very simply, store the current station index in a text file
        try:
            f = open(LASTSTATION, "w")
            f.write(str(self.curStation))
            f.close()
    
        except (OSError, IOError):
            print ("Error saving current track");

    def playNext(self):
        #
        # Play next station available
        # Returns: caption of the new station
        print("playNext - curStation = " + str(self.curStation))
        if self.curStation < len(self.stationCaption) :
            self.curStation += 1
            print("curStation = " + str(self.curStation))
            self.play()
        return self.stationCaption[self.curStation-1]
 
    def playPrevious(self):
        #
        # Play previous station available
        # Returns: caption of the new station
        print("playPrevious - curStation = " + str(self.curStation))
        if self.curStation > 1 :
            self.curStation -= 1
            print("curStation = " + str(self.curStation))
            self.play()
        return self.stationCaption[self.curStation-1]

        
    def setVolume(self, newvolume):
        #
        # Set volume
        # Returns: new volume
        if newvolume < 0:
            newvolume = 0
        if newvolume > 100:
            newvolume = 100
            
        self.volume = newvolume
        os.system("mpc volume " + str(self.volume))
        return self.volume
    
    def changeVolume(self, delta):
        #
        # Increase volume by delta%
        # Returns: new volume
        newvolume = self.volume + delta
        if newvolume < 0:
            newvolume = 0
        if newvolume > 100:
            newvolume = 100
            
        self.volume = newvolume
        os.system("mpc volume " + str(self.volume))
        return self.volume
            
            
    def getVolume(self):
        #
        return self.volume
        
     
